<?php
 namespace WizyTowka\_Private; use WizyTowka as __; class HooksManager { private $_actions = []; private $_filters = []; public function addAction(string $name, callable $callback) : void { $this->_addHook($this->_actions, $name, $callback); } public function addFilter(string $name, callable $callback) : void { $this->_addHook($this->_filters, $name, $callback); } private function _addHook(array &$hooks, string $name, callable $callback) : void { $hooks[$name][] = $callback; } public function removeAction(string $name, callable $callback) : void { $this->_removeHook($this->_actions, $name, $callback); } public function removeFilter(string $name, callable $callback) : void { $this->_removeHook($this->_filters, $name, $callback); } private function _removeHook(array &$hooks, string $name, callable $callback) : void { if (!isset($hooks[$name])) { throw HooksManagerException::hookDoesNotExist($name); } foreach ($hooks[$name] as $key => $iteratedCallback) { if ($iteratedCallback === $callback) { unset($hooks[$name][$key]); } } } public function runAction(string $name, ...$arguments) : void { $this->_runHook($this->_actions, $name, $arguments); } public function applyFilter(string $name, ...$arguments) { if (!isset($arguments[0])) { throw HooksManagerException::filterRequiresArgument($name); } return $this->_runHook($this->_filters, $name, $arguments, true); } private function _runHook(array &$hooks, string $name, array $arguments, bool $keepFirstArgument = false) { if (!isset($hooks[$name])) { return $keepFirstArgument ? $arguments[0] : null; } foreach ($hooks[$name] as $callback) { try { if ($keepFirstArgument) { $arguments[0] = $callback(...$arguments); } else { $callback(...$arguments); } } catch (\ArgumentCountError $e) { throw HooksManagerException::hookWrongArgumentsCount( $name, (new \ReflectionFunction($callback))->getNumberOfRequiredParameters(), count($arguments) ); } catch (\ErrorException $e) { $requiredArgsCount = (new \ReflectionFunction($callback))->getNumberOfRequiredParameters(); $givenArgsCount = count($arguments); if ($requiredArgsCount > $givenArgsCount) { throw HooksManagerException::hookWrongArgumentsCount($name, $requiredArgsCount, $givenArgsCount); } else { throw $e; } } } return $keepFirstArgument ? $arguments[0] : null; } } class HooksManagerException extends __\Exception { static public function hookWrongArgumentsCount($hookName, $requiredArgsCount, $givenArgsCount) { return new self('Callback of ' . $hookName . ' hook expect ' . $requiredArgsCount . ' required arguments, ' . $givenArgsCount . ' given.', 1); } static public function hookDoesNotExist($hookName) { return new self('Hook named ' . $hookName . ' does not exists.', 2); } static public function filterRequiresArgument($hookName) { return new self('Filter ' . $hookName . ' always requires one argument at least.', 3); } }